diff --git a/src/backend/commands/alter.c b/src/backend/commands/alter.c
index 40044070cf..801f6eddb6 100644
--- a/src/backend/commands/alter.c
+++ b/src/backend/commands/alter.c
@@ -374,6 +374,49 @@ ExecRenameStmt(RenameStmt *stmt)
 		case OBJECT_TYPE:
 			return RenameType(stmt);
 
+		case OBJECT_STATISTIC_EXT:
+			{
+				ObjectAddress address;
+				Relation	catalog;
+				Relation	relation = NULL;
+
+				address = get_object_address(stmt->renameType,
+											 stmt->object,
+											 &relation,
+											 AccessExclusiveLock,
+											 stmt->missing_ok);
+				Assert(relation == NULL);
+
+				if (OidIsValid(address.objectId))
+				{
+					catalog = table_open(address.classId, RowExclusiveLock);
+					AlterObjectRename_internal(catalog,
+											   address.objectId,
+											   stmt->newname);
+					table_close(catalog, RowExclusiveLock);
+				}
+				else
+				{
+					char	   *schemaname;
+					char	   *statname;
+
+					Assert(stmt->missing_ok);
+
+					DeconstructQualifiedName(castNode(List, stmt->object), &schemaname, &statname);
+
+					if (schemaname)
+						ereport(NOTICE,
+								(errmsg("statistics object \"%s.%s\" does not exist, skipping",
+										schemaname, statname)));
+					else
+						ereport(NOTICE,
+								(errmsg("statistics object \"%s\" does not exist, skipping",
+										statname)));
+				}
+
+				return address;
+			}
+
 		case OBJECT_AGGREGATE:
 		case OBJECT_COLLATION:
 		case OBJECT_CONVERSION:
@@ -386,7 +429,6 @@ ExecRenameStmt(RenameStmt *stmt)
 		case OBJECT_LANGUAGE:
 		case OBJECT_PROCEDURE:
 		case OBJECT_ROUTINE:
-		case OBJECT_STATISTIC_EXT:
 		case OBJECT_TSCONFIGURATION:
 		case OBJECT_TSDICTIONARY:
 		case OBJECT_TSPARSER:
@@ -521,6 +563,51 @@ ExecAlterObjectSchemaStmt(AlterObjectSchemaStmt *stmt,
 										 oldSchemaAddr ? &oldNspOid : NULL);
 			break;
 
+		case OBJECT_STATISTIC_EXT:
+			{
+				Relation	catalog;
+				Relation	relation;
+				Oid			classId;
+				Oid			nspOid;
+
+				address = get_object_address(stmt->objectType,
+											 stmt->object,
+											 &relation,
+											 AccessExclusiveLock,
+											 stmt->missing_ok);
+
+				if (OidIsValid(address.objectId))
+				{
+					Assert(relation == NULL);
+					classId = address.classId;
+					catalog = table_open(classId, RowExclusiveLock);
+					nspOid = LookupCreationNamespace(stmt->newschema);
+
+					oldNspOid = AlterObjectNamespace_internal(catalog, address.objectId,
+															  nspOid);
+					table_close(catalog, RowExclusiveLock);
+				}
+				else
+				{
+					char	   *schemaname;
+					char	   *statname;
+
+					Assert(stmt->missing_ok);
+
+					DeconstructQualifiedName(castNode(List, stmt->object), &schemaname, &statname);
+
+					if (schemaname)
+						ereport(NOTICE,
+								(errmsg("statistics object \"%s.%s\" does not exist, skipping",
+										schemaname, statname)));
+					else
+						ereport(NOTICE,
+								(errmsg("statistics object \"%s\" does not exist, skipping",
+										statname)));
+				}
+			}
+			break;
+
 			/* generic code path */
 		case OBJECT_AGGREGATE:
 		case OBJECT_COLLATION:
@@ -531,7 +618,6 @@ ExecAlterObjectSchemaStmt(AlterObjectSchemaStmt *stmt,
 		case OBJECT_OPFAMILY:
 		case OBJECT_PROCEDURE:
 		case OBJECT_ROUTINE:
-		case OBJECT_STATISTIC_EXT:
 		case OBJECT_TSCONFIGURATION:
 		case OBJECT_TSDICTIONARY:
 		case OBJECT_TSPARSER:
diff --git a/src/backend/parser/gram.y b/src/backend/parser/gram.y
index d0eb80e69c..878e9152f6 100644
--- a/src/backend/parser/gram.y
+++ b/src/backend/parser/gram.y
@@ -8955,6 +8955,15 @@ RenameStmt: ALTER AGGREGATE aggregate_with_argtypes RENAME TO name
 					n->missing_ok = false;
 					$$ = (Node *)n;
 				}
+			| ALTER STATISTICS IF_P EXISTS any_name RENAME TO name
+				{
+					RenameStmt *n = makeNode(RenameStmt);
+					n->renameType = OBJECT_STATISTIC_EXT;
+					n->object = (Node *) $5;
+					n->newname = $8;
+					n->missing_ok = true;
+					$$ = (Node *)n;
+				}
 			| ALTER TEXT_P SEARCH PARSER any_name RENAME TO name
 				{
 					RenameStmt *n = makeNode(RenameStmt);
@@ -9223,6 +9232,15 @@ AlterObjectSchemaStmt:
 					n->missing_ok = false;
 					$$ = (Node *)n;
 				}
+			| ALTER STATISTICS IF_P EXISTS any_name SET SCHEMA name
+				{
+					AlterObjectSchemaStmt *n = makeNode(AlterObjectSchemaStmt);
+					n->objectType = OBJECT_STATISTIC_EXT;
+					n->object = (Node *) $5;
+					n->newschema = $8;
+					n->missing_ok = true;
+					$$ = (Node *)n;
+				}
 			| ALTER TEXT_P SEARCH PARSER any_name SET SCHEMA name
 				{
 					AlterObjectSchemaStmt *n = makeNode(AlterObjectSchemaStmt);
